# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,AoristicSum)
S3method(as.data.frame,IncrementTest)
S3method(as.data.frame,MeanDate)
S3method(coef,EventDate)
S3method(fitted,EventDate)
S3method(hist,RefinePermutationOrder)
S3method(image,AoristicSum)
S3method(plot,AoristicSum)
S3method(plot,EventDate)
S3method(plot,IncrementTest)
S3method(plot,MeanDate)
S3method(plot,RateOfChange)
S3method(plot,SimulationMeanDate)
S3method(residuals,EventDate)
S3method(sigma,EventDate)
S3method(simulate,MeanDate)
S3method(summary,EventDate)
S3method(terms,EventDate)
export(get_order)
exportMethods("[")
exportMethods("[[")
exportMethods(aoristic)
exportMethods(apportion)
exportMethods(as.data.frame)
exportMethods(as_seriation)
exportMethods(assess)
exportMethods(bootstrap)
exportMethods(coef)
exportMethods(density_accumulation)
exportMethods(density_event)
exportMethods(event)
exportMethods(fit)
exportMethods(fitted)
exportMethods(get_order)
exportMethods(hist)
exportMethods(image)
exportMethods(jackknife)
exportMethods(mcd)
exportMethods(order_columns)
exportMethods(order_rows)
exportMethods(permute)
exportMethods(plot)
exportMethods(plot_time)
exportMethods(predict_accumulation)
exportMethods(predict_event)
exportMethods(refine)
exportMethods(residuals)
exportMethods(roc)
exportMethods(seriate_average)
exportMethods(seriate_rank)
exportMethods(seriate_refine)
exportMethods(sigma)
exportMethods(simulate)
exportMethods(span)
exportMethods(summary)
exportMethods(terms)
exportMethods(time)
exportMethods(weights)
import(aion)
import(arkhe)
importClassesFrom(aion,RataDie)
importClassesFrom(aion,TimeSeries)
importClassesFrom(dimensio,CA)
importFrom(extraDistr,ptnorm)
importFrom(grDevices,xy.coords)
importFrom(methods,.valueClassTest)
importFrom(methods,as)
importFrom(methods,callGeneric)
importFrom(methods,callNextMethod)
importFrom(methods,new)
importFrom(methods,setClass)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(methods,validObject)
importMethodsFrom(arkhe,bootstrap)
importMethodsFrom(arkhe,jackknife)
